@@ -5,13 +5,14 @@ from psycopg import Error, InterfaceError, InternalError, OperationalError
 
 
 class RetryRowStrategy(ABC):
-    """Abstract base class that specifies an interface for various strategies to determine if the element should be
-    retried.
+    """Abstract base class that specifies an interface for various strategies to
+    determine if the element should be retried.
     """
 
     @abstractmethod
     def should_retry(self, element: Any, error: Error) -> bool:
-        """Returns bool for given element and error if the transform should retry the element.
+        """Returns bool for given element and error if the transform should
+        retry the element.
 
         Args:
             element: The element that raised the error.
@@ -31,13 +32,14 @@ class AlwaysRetryRowStrategy(RetryRowStrategy):
 
 
 class RetryRowOnTransientErrorStrategy(RetryRowStrategy):
-    """RetryRowStrategy implementation that allows retry of elements with transient errors."""
+    """RetryRowStrategy implementation that allows retry of elements with
+    transient errors."""
 
-    _TRANSIENT_ERRORS = [
+    _TRANSIENT_ERRORS = (
         OperationalError,
         InternalError,
         InterfaceError,
-    ]
+    )
 
     def should_retry(self, element: Any, error: Error) -> bool:
-        return type(error) in self._TRANSIENT_ERRORS
+        return isinstance(error, self._TRANSIENT_ERRORS)
